import { useMemo } from 'react';

export const VoronoiOerlay = ({
  innerWidth,
  innerHeight,
  allData,
  lineGenerator,
  onHover,
}) => {
  return useMemo(() => {
    const points = allData.map((d) => [
      lineGenerator.x()(d),
      lineGenerator.y()(d),
    ]);

    const delaunay = d3.Delaunay.from(points);

    const voronoi = delaunay.voronoi([
      0,
      0,
      innerWidth,
      innerHeight,
    ]);

    return (
      <g className="voronoi">
        {points.map((point, i) => (
          <path
           
            d={voronoi.renderCell(i)}
            onMouseEnter={() => onHover(allData[i])}
          ></path>
        ))}
      </g>
    );
  }, [
    allData,
    lineGenerator,
    innerWidth,
    innerHeight,
    onHover,
  ]);
};
